<!-- 
TEI XSLT stylesheet family version 2.1
RCS: $Id: teihtml.xsl,v 1.9 2000/05/08 16:21:13 rahtz Exp rahtz $

XSL stylesheet to format TEI Lite XML documents to HTML or XSL FO

 Copyright 1999-2003 Sebastian Rahtz/Oxford University  

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     
    The author may be contacted via the e-mail address
 
    sebastian.rahtz@oucs.ox.ac.uk
--> 
<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  version="1.0"
  xmlns:html="http://www.w3.org/1999/xhtml">

<xsl:import href="teihtml.xsl"/>

<xsl:output 
  method="html"  
  doctype-public="-//W3C//DTD HTML 4.0 Transitional//EN" 
  doctype-system="http://www.w3.org/TR/html4/loose.dtd"
  indent="no"/>

<!-- parameterization -->

<xsl:template name="metaHook">
  <xsl:param name="title"/>
 <meta name="DC.Title" content="{$title}"/>
 <meta name="DC.Language" content="(SCHEME=iso639) en"/> 
 <meta name="DC.Creator" content="TEI,Oxford University Computing Services, 13 Banbury Road, Oxford OX2 6NN, United Kingdom"/>
 <meta name="DC.Creator.Address" content="tei@oucs.ox.ac.uk"/>
</xsl:template>

<xsl:template name="bodyHook">
  <xsl:attribute name="background">/Pictures/background.gif</xsl:attribute>
</xsl:template>

<!-- *************** params ************************** -->
<xsl:param name="STDOUT">true</xsl:param>
<xsl:param name="alignNavigationPanel"></xsl:param>
<xsl:param name="authorWord"></xsl:param>
<xsl:param name="autoToc"></xsl:param>
<xsl:param name="bottomNavigationPanel">true</xsl:param>
<xsl:param name="cssFile">/Stylesheets/tei.css</xsl:param>
<xsl:param name="dateWord"></xsl:param>
<xsl:param name="feedbackURL">http://www.tei-c.org/Consortium/TEI-contact.html</xsl:param>
<xsl:param name="feedbackWords">Contact</xsl:param>
<xsl:param name="homeURL">http://www.tei-c.org/</xsl:param>
<xsl:param name="homeWords">TEI Home</xsl:param>
<xsl:param name="institution">Text Encoding Initiative</xsl:param>
<xsl:param name="leftLinks">true</xsl:param>
<xsl:param name="linksWidth">20%</xsl:param>
<xsl:param name="numberHeadings"></xsl:param>
<xsl:param name="parentURL"></xsl:param>
<xsl:param name="parentWords"></xsl:param>
<xsl:param name="searchURL">http://search.ox.ac.uk/web/related/natproj/tei</xsl:param>
<xsl:param name="searchWords">Search this site</xsl:param>
<xsl:param name="showTitleAuthor">1</xsl:param>
<xsl:param name="subTocDepth">-1</xsl:param>
<xsl:param name="topNavigationPanel"></xsl:param>
<xsl:template name="copyrightStatement">Copyright TEI Consortium 2003</xsl:template>
<xsl:template name="logoPicture">
<img src="/Pictures/jaco001d.gif" alt="" width="180" />
</xsl:template>


<xsl:template match="html:*">
     <xsl:element name="{local-name()}">
       <xsl:copy-of select="@*"/>
       <xsl:apply-templates/>
     </xsl:element>
</xsl:template>


<xsl:template match="formerrors">
    <xsl:apply-templates select="..//error"/>
</xsl:template>

<xsl:template match="error">
  <br/>
   <span class="form_error"><xsl:value-of select="."/></span>
</xsl:template>

<xsl:template match="textfield">
    <input 
        type="text"
        name="{@name|name}" 
        value="{@value|value}" 
        size="{@width|width}" 
        maxlength="{@maxlength|maxlength}" />
    <xsl:apply-templates select="error"/>
</xsl:template>

<xsl:template match="password">
    <input 
        type="password"
        name="{@name|name}" 
        value="{@value|value}" 
        size="{@width|width}" 
        maxlength="{@maxlength|maxlength}" />
    <xsl:apply-templates select="error"/>
</xsl:template>

<xsl:template match="checkbox">
    <input
        type="checkbox"
        name="{@name|name}"
        value="{@value|value}" >
      <xsl:if test="@checked|checked">
        <xsl:attribute name="checked">
	  <xsl:text>@checked|checked</xsl:text>
	</xsl:attribute>
      </xsl:if>
    </input>
    <xsl:apply-templates select="error"/>
</xsl:template>

<xsl:template match="submit_button">
    <input
        type="submit"
        name="{@name|name}"
        value="{@value|value}" />
    <xsl:apply-templates select="error"/>
</xsl:template>

<xsl:template match="hidden">
    <input
        type="hidden"
        name="{@name|name}"
        value="{@value|value}" />
</xsl:template>

<xsl:template match="options/option">
  <option value="{@value|value}">
    <xsl:if test="selected[. = 'selected'] | @selected[. = 'selected']">
      <xsl:attribute name="selected">selected</xsl:attribute>
    </xsl:if>
    <xsl:value-of select="@text|text"/>
  </option>
</xsl:template>

<xsl:template match="single_select">
    <select name="{@name|name}">
    <xsl:if test="@size">
      <xsl:attribute name="size"><xsl:value-of select="@size"/></xsl:attribute>
    </xsl:if>
        <xsl:apply-templates select="options/option"/>
    </select>
    <xsl:apply-templates select="error"/>
</xsl:template>

<xsl:template match="multi_select">
    <select multiple="multiple" size="5" name="{@name|name}">
    <xsl:if test="@size">
      <xsl:attribute name="size"><xsl:value-of select="@size"/></xsl:attribute>
    </xsl:if>
        <xsl:apply-templates select="options/option"/>
    </select>
    <xsl:apply-templates select="error"/>
</xsl:template>

<xsl:template match="textarea">
    <textarea name="{@name|name}" cols="{@cols|cols}" rows="{@rows|rows}">
    <xsl:if test="@wrap|wrap"><xsl:attribute name="wrap">physical</xsl:attribute></xsl:if>
    <xsl:value-of select="@value|value"/>
    </textarea> <br />
    <xsl:apply-templates select="error"/>
</xsl:template>

<xsl:template match="form">
  <xsl:copy>
    <xsl:copy-of select="@*"/>
    <xsl:apply-templates/>
  </xsl:copy>
</xsl:template>


   <xsl:template match="p/name">
     <b><xsl:apply-templates/></b>
   </xsl:template>

<!-- templates to match Syd's boffo <action> tags -->

   <xsl:template match="note[@type='action']" >
     <p align="right">
       <b>Action <xsl:value-of select="label"/> by <xsl:value-of select="date"/> </b>
       <xsl:text>: </xsl:text>
       <xsl:apply-templates select="text()"/>
</p>

   </xsl:template>

   <xsl:template match="note[@type='action']" mode="table">
     <tr>
       <td><xsl:value-of select="label"/></td>
       <td><xsl:apply-templates select="text()"/></td>
       <td><xsl:value-of select="date"/> </td>
     </tr>
   </xsl:template>

   <xsl:template match="action" >
     <p align="right">
       <b>Action <xsl:value-of select="name"/> by <xsl:value-of select="dueDate"/> </b>
       <xsl:text>: </xsl:text>
       <xsl:apply-templates select="resp"/>
</p>

   </xsl:template>

   <xsl:template match="front">
     <xsl:apply-templates/>
     <xsl:if test="//note[@type='action']">
     <h4>Actions</h4>
     <table>
       <tr>
        <td>Resp</td><td>action</td><td>due date</td>
       </tr>
     <xsl:apply-templates select="//note[@type='action']" mode="table"/>
</table>
     </xsl:if>

   </xsl:template>


</xsl:stylesheet>


